@@ -7,14 +7,18 @@ from lettuce import world
 from nose.tools import assert_equals, assert_true, assert_is_not_none, assert_is_none, assert_false
 
 
+TIMEOUT=3
+
 def wait_for_automation_server():
     logger.info('waiting for automation server')
     while (True):
         time.sleep(0.5)
         try:
-            response = requests.get("http://localhost:5123/ping")
+            response = requests.get("http://localhost:5123/ping", timeout=TIMEOUT)
             if response.status_code == 200:
                 break
+        except requests.exceptions.Timeout as ex:
+            logger.debug(u'pqaut timed out waiting for automation server: {}'.format(ex))
         except Exception as ex:
             logger.debug(u'error occurred while waiting for automation server: {}'.format(ex))
             pass
@@ -25,7 +29,12 @@ def tap(name, automation_type = None):
     time.sleep(0.4)
     headers = {'Content-type': 'application/json', 'Accept': 'application/json' }
     body = {'query':{'window_name':'', 'value':name, 'automation_type':automation_type}}
-    response = requests.post('http://localhost:5123/click', data=json.dumps(body), headers=headers)
+    try:
+        response = requests.post('http://localhost:5123/click', data=json.dumps(body), headers=headers, timeout=TIMEOUT)
+    except requests.exceptions.Timeout as ex:
+        logger.debug(u'pqaut timed out tapping on {}: {}'.format(name, ex))
+    except Exception as ex:
+        logger.debug(u'error occurred while tapping on {}: {}'.format(name, ex))
     time.sleep(0.3)
 
 def assert_is_not_visible(name, automation_type = None, timeout=3):
@@ -43,6 +52,10 @@ def _wait_for_element_to_not_be_visible(name, automation_type, timeout):
         try:
             logger.debug(u'trying to find invisible element {} with type {}'.format(name, automation_type))
             found_element = _find_element(name, automation_type)
+        except requests.exceptions.Timeout as ex:
+            logger.debug(u'pqaut timed out while looking for {}: {}'.format(name, ex))
+            time.sleep(delay)
+            continue
         except requests.exceptions.ConnectionError as ex:
             logger.debug(u'error occurred while looking for element: {}'.format(ex))
             time.sleep(delay)
@@ -64,6 +77,10 @@ def _wait_for_visible_element(name, automation_type, timeout):
         try:
             logger.debug(u'trying to find element {} with type {}'.format(name, automation_type))
             found_element = _find_element(name, automation_type)
+        except requests.exceptions.Timeout as ex:
+            logger.debug(u'pqaut timed out while looking for {}: {}'.format(name, ex))
+            time.sleep(delay)
+            continue
         except requests.exceptions.ConnectionError as ex:
             logger.debug(u'error occurred while looking for element: {}'.format(ex))
             time.sleep(delay)
@@ -82,7 +99,7 @@ def _element_is_visible(element):
 def _find_element(name, automation_type):
     headers = {'Content-type': 'application/json', 'Accept': 'application/json' }
     body = {'query':{'window_name':'', 'value':name, 'automation_type':automation_type}}
-    response = requests.post('http://localhost:5123/find_element', data=json.dumps(body), headers=headers)
+    response = requests.post('http://localhost:5123/find_element', data=json.dumps(body), headers=headers, timeout=TIMEOUT)
     found_element = response.json()
     if len(found_element.keys()) == 0:
         return None
